@@ -4,15 +4,17 @@ from . import base
 from .. import tl
 import numpy as np
 import matplotlib.pyplot as plt
+from ..io._util import _check_upgrade_schema
 
 
+@_check_upgrade_schema()
 def alpha_diversity(
     adata: AnnData,
     groupby: str,
     *,
-    target_col: str = "clonotype",
+    target_col: str = "clone_id",
     vistype: Literal["bar"] = "bar",
-    **kwargs
+    **kwargs,
 ) -> plt.Axes:
     """Plot the alpha diversity per group.
 
